@@ -797,23 +797,23 @@ levent_schedule_cleanup(struct lldpd *cfg)
 	}
 
 	/* Compute the next TTL event */
-	struct timeval tv = { LOCAL_CHASSIS(cfg)->c_ttl, 0 };
+	struct timeval tv = { cfg->g_config.c_ttl, 0 };
 	time_t now = time(NULL);
 	time_t next;
 	struct lldpd_hardware *hardware;
 	struct lldpd_port *port;
 	TAILQ_FOREACH(hardware, &cfg->g_hardware, h_entries) {
 		TAILQ_FOREACH(port, &hardware->h_rports, p_entries) {
-			if (now >= port->p_lastupdate + port->p_chassis->c_ttl) {
+			if (now >= port->p_lastupdate + port->p_ttl) {
 				tv.tv_sec = 0;
 				log_debug("event", "immediate cleanup on port %s (%lld, %d, %lld)",
 				    hardware->h_ifname,
 				    (long long)now,
-				    port->p_chassis->c_ttl,
+				    port->p_ttl,
 				    (long long)port->p_lastupdate);
 				break;
 			}
-			next = port->p_chassis->c_ttl - (now - port->p_lastupdate);
+			next = port->p_ttl - (now - port->p_lastupdate);
 			if (next < tv.tv_sec)
 				tv.tv_sec = next;
 		}
