@@ -288,43 +288,43 @@ iflinux_get_permanent_mac_ethtool(struct lldpd *cfg,
     struct interfaces_device_list *interfaces,
     struct interfaces_device *iface)
 {
+	int ret = -1;
 	struct ifreq ifr = {};
-	union {
-		struct ethtool_perm_addr addr;
-		/* cppcheck-suppress unusedStructMember */
-		char u8[sizeof(struct ethtool_perm_addr) + ETHER_ADDR_LEN];
-	} epaddr;
+	struct ethtool_perm_addr *epaddr = calloc(sizeof(struct ethtool_perm_addr) + ETHER_ADDR_LEN, 1);
+	if (epaddr == NULL) goto end;
 
 	strlcpy(ifr.ifr_name, iface->name, sizeof(ifr.ifr_name));
-	epaddr.addr.cmd = ETHTOOL_GPERMADDR;
-	epaddr.addr.size = ETHER_ADDR_LEN;
-	ifr.ifr_data = (caddr_t)&epaddr.addr;
+	epaddr->cmd = ETHTOOL_GPERMADDR;
+	epaddr->size = ETHER_ADDR_LEN;
+	ifr.ifr_data = (caddr_t)epaddr;
 	if (ioctl(cfg->g_sock, SIOCETHTOOL, &ifr) == -1) {
 		static int once = 0;
 		if (errno == EPERM && !once) {
-			log_warn("interfaces",
+			log_warnx("interfaces",
 			    "no permission to get permanent MAC address for %s (requires 2.6.19+)",
 			    iface->name);
 			once = 1;
-			return -1;
+			goto end;
 		}
 		if (errno != EPERM)
-			log_warnx("interfaces", "cannot get permanent MAC address for %s",
+			log_warn("interfaces", "cannot get permanent MAC address for %s",
 			    iface->name);
-		return -1;
+		goto end;
 	}
-	if (epaddr.addr.data[0] != 0 ||
-	    epaddr.addr.data[1] != 0 ||
-	    epaddr.addr.data[2] != 0 ||
-	    epaddr.addr.data[3] != 0 ||
-	    epaddr.addr.data[4] != 0 ||
-	    epaddr.addr.data[5] != 0 ||
-	    epaddr.addr.data[6] != 0) {
-		memcpy(iface->address, epaddr.addr.data, ETHER_ADDR_LEN);
-		return 0;
+	if (epaddr->data[0] != 0 ||
+	    epaddr->data[1] != 0 ||
+	    epaddr->data[2] != 0 ||
+	    epaddr->data[3] != 0 ||
+	    epaddr->data[4] != 0 ||
+	    epaddr->data[5] != 0) {
+		memcpy(iface->address, epaddr->data, ETHER_ADDR_LEN);
+		ret = 0;
+		goto end;
 	}
-	log_debug("interfaces", "cannot get permanent MAC for %s", iface->name);
-	return -1;
+	log_debug("interfaces", "cannot get permanent MAC for %s (all 0)", iface->name);
+ end:
+	free(epaddr);
+	return ret;
 }
 
 /**
@@ -446,21 +446,21 @@ struct ethtool_link_usettings {
 	} link_modes;
 };
 
-static inline int
+static int
 iflinux_ethtool_link_mode_test_bit(unsigned int nr, const uint32_t *mask)
 {
 	if (nr >= 32 * ETHTOOL_LINK_MODE_MASK_MAX_KERNEL_NU32)
 		return 0;
 	return !!(mask[nr / 32] & (1 << (nr % 32)));
 }
-static inline void
+static void
 iflinux_ethtool_link_mode_unset_bit(unsigned int nr, uint32_t *mask)
 {
 	if (nr >= 32 * ETHTOOL_LINK_MODE_MASK_MAX_KERNEL_NU32)
 		return;
 	mask[nr / 32] &= ~(1 << (nr % 32));
 }
-static inline int
+static int
 iflinux_ethtool_link_mode_is_empty(const uint32_t *mask)
 {
 	for (unsigned int i = 0;
@@ -498,9 +498,10 @@ iflinux_ethtool_glink(struct lldpd *cfg, const char *ifname, struct ethtool_link
 		} else {
 			static int once = 0;
 			if (errno == EPERM && !once) {
-				log_warn("interfaces",
+				log_warnx("interfaces",
 				    "cannot get ethtool link information "
-				    "with GLINKSETTINGS (requires 4.9+)");
+				    "with GLINKSETTINGS (requires 4.9+). "
+				    "25G+ speeds may be missing in MAC/PHY TLVs");
 				once = 1;
 			}
 			nwords = -1;
@@ -555,9 +556,10 @@ iflinux_ethtool_glink(struct lldpd *cfg, const char *ifname, struct ethtool_link
 	} else {
 		static int once = 0;
 		if (errno == EPERM && !once) {
-			log_warn("interfaces",
+			log_warnx("interfaces",
 			    "cannot get ethtool link information "
-			    "with GSET (requires 2.6.19+)");
+			    "with GSET (requires 2.6.19+). "
+			    "MAC/PHY TLV will be unavailable");
 			once = 1;
 		}
 	}
@@ -669,6 +671,7 @@ iflinux_macphy(struct lldpd *cfg, struct lldpd_hardware *hardware)
 #endif /* ENABLE_DOT3 */
 
 
+#ifdef ENABLE_OLDIES
 struct bond_master {
 	char name[IFNAMSIZ];
 	int  index;
@@ -845,6 +848,7 @@ iflinux_handle_bond(struct lldpd *cfg, struct interfaces_device_list *interfaces
 		hardware->h_mtu = iface->mtu ? iface->mtu : 1500;
 	}
 }
+#endif
 
 /* Query each interface to get the appropriate driver */
 static void
@@ -1030,7 +1034,9 @@ interfaces_update(struct lldpd *cfg)
 	iflinux_add_physical(cfg, interfaces);
 
 	interfaces_helper_whitelist(cfg, interfaces);
+#ifdef ENABLE_OLDIES
 	iflinux_handle_bond(cfg, interfaces);
+#endif
 	interfaces_helper_physical(cfg, interfaces,
 	    &eth_ops,
 	    iflinux_eth_init);
