@@ -93,7 +93,7 @@ netlink_connect(struct lldpd *cfg, int protocol, unsigned groups)
 	int s;
 	struct sockaddr_nl local = {
 		.nl_family = AF_NETLINK,
-		.nl_pid = getpid(),
+		.nl_pid = 0,
 		.nl_groups = groups
 	};
 
@@ -606,7 +606,7 @@ retry:
 					TAILQ_FOREACH(ifaold, ifas, next) {
 						if ((ifaold->index == ifanew->index) &&
 						    !memcmp(&ifaold->address, &ifanew->address,
-							sizeof(ifaold->address))) continue;
+							sizeof(ifaold->address))) break;
 					}
 					if (getnameinfo((struct sockaddr *)&ifanew->address,
 						sizeof(ifanew->address),
