@@ -66,84 +66,84 @@ ATOM_MAP_REGISTER(port_status_map, 3);
 
 #ifdef ENABLE_DOT3
 static lldpctl_map_t operational_mau_type_values[] = {
-	{ 1,	"AUI - no internal MAU, view from AUI" },
-	{ 2,	"10Base5 - thick coax MAU" },
-	{ 3,	"Foirl - FOIRL MAU" },
-	{ 4,	"10Base2 - thin coax MAU" },
-	{ 5,	"10BaseT - UTP MAU" },
-	{ 6,	"10BaseFP - passive fiber MAU" },
-	{ 7,	"10BaseFB - sync fiber MAU" },
-	{ 8,	"10BaseFL - async fiber MAU" },
-	{ 9,	"10Broad36 - broadband DTE MAU" },
-	{ 10,	"10BaseTHD - UTP MAU, half duplex mode" },
-	{ 11,	"10BaseTFD - UTP MAU, full duplex mode" },
-	{ 12,	"10BaseFLHD - async fiber MAU, half duplex mode" },
-	{ 13,	"10BaseFLDF - async fiber MAU, full duplex mode" },
-	{ 14,	"10BaseT4 - 4 pair category 3 UTP" },
-	{ 15,	"100BaseTXHD - 2 pair category 5 UTP, half duplex mode" },
-	{ 16,	"100BaseTXFD - 2 pair category 5 UTP, full duplex mode" },
-	{ 17,	"100BaseFXHD - X fiber over PMT, half duplex mode" },
-	{ 18,	"100BaseFXFD - X fiber over PMT, full duplex mode" },
-	{ 19,	"100BaseT2HD - 2 pair category 3 UTP, half duplex mode" },
-	{ 20,	"100BaseT2FD - 2 pair category 3 UTP, full duplex mode" },
-	{ 21,	"1000BaseXHD - PCS/PMA, unknown PMD, half duplex mode" },
-	{ 22,	"1000BaseXFD - PCS/PMA, unknown PMD, full duplex mode" },
-	{ 23,	"1000BaseLXHD - Fiber over long-wavelength laser, half duplex mode" },
-	{ 24,	"1000BaseLXFD - Fiber over long-wavelength laser, full duplex mode" },
-	{ 25,	"1000BaseSXHD - Fiber over short-wavelength laser, half duplex mode" },
-	{ 26,	"1000BaseSXFD - Fiber over short-wavelength laser, full duplex mode" },
-	{ 27,	"1000BaseCXHD - Copper over 150-Ohm balanced cable, half duplex mode" },
-	{ 28,	"1000BaseCXFD - Copper over 150-Ohm balanced cable, full duplex mode" },
-	{ 29,	"1000BaseTHD - Four-pair Category 5 UTP, half duplex mode" },
-	{ 30,	"1000BaseTFD - Four-pair Category 5 UTP, full duplex mode" },
-	{ 31,	"10GigBaseX - X PCS/PMA, unknown PMD." },
-	{ 32,	"10GigBaseLX4 - X fiber over WWDM optics" },
-	{ 33,	"10GigBaseR - R PCS/PMA, unknown PMD." },
-	{ 34,	"10GigBaseER - R fiber over 1550 nm optics" },
-	{ 35,	"10GigBaseLR - R fiber over 1310 nm optics" },
-	{ 36,	"10GigBaseSR - R fiber over 850 nm optics" },
-	{ 37,	"10GigBaseW - W PCS/PMA, unknown PMD." },
-	{ 38,	"10GigBaseEW - W fiber over 1550 nm optics" },
-	{ 39,	"10GigBaseLW - W fiber over 1310 nm optics" },
-	{ 40,	"10GigBaseSW - W fiber over 850 nm optics" },
-	{ 41,	"10GigBaseCX4 - X copper over 8 pair 100-Ohm balanced cable" },
-	{ 42,	"2BaseTL - Voice grade UTP copper, up to 2700m, optional PAF" },
-	{ 43,	"10PassTS - Voice grade UTP copper, up to 750m, optional PAF" },
-	{ 44,	"100BaseBX10D - One single-mode fiber OLT, long wavelength, 10km" },
-	{ 45,	"100BaseBX10U - One single-mode fiber ONU, long wavelength, 10km" },
-	{ 46,	"100BaseLX10 - Two single-mode fibers, long wavelength, 10km" },
-	{ 47,	"1000BaseBX10D - One single-mode fiber OLT, long wavelength, 10km" },
-	{ 48,	"1000BaseBX10U - One single-mode fiber ONU, long wavelength, 10km" },
-	{ 49,	"1000BaseLX10 - Two sigle-mode fiber, long wavelength, 10km" },
-	{ 50,	"1000BasePX10D - One single-mode fiber EPON OLT, 10km" },
-	{ 51,	"1000BasePX10U - One single-mode fiber EPON ONU, 10km" },
-	{ 52,	"1000BasePX20D - One single-mode fiber EPON OLT, 20km" },
-	{ 53,	"1000BasePX20U - One single-mode fiber EPON ONU, 20km" },
-	{ 54,	"10GbaseT - Four-pair Category 6A or better, full duplex mode only" },
-	{ 55,	"10GbaseLRM - R multimode fiber over 1310 nm optics" },
-	{ 56,	"1000baseKX - X backplane, full duplex mode only" },
-	{ 57,	"10GbaseKX4 - 4 lane X backplane, full duplex mode only" },
-	{ 58,	"10GbaseKR - R backplane, full duplex mode only" },
-	{ 59,	"10G1GbasePRXD1 - One single-mode fiber asymmetric-rate EPON OLT, low power budget (PRX10)" },
-	{ 60,   "10G1GbasePRXD2 - One single-mode fiber asymmetric-rate EPON OLT, medium power budget (PRX20)" },
-	{ 61,   "10G1GbasePRXD3 - One single-mode fiber asymmetric-rate EPON OLT, high power budget (PRX30)" },
-	{ 62,   "10G1GbasePRXU1 - One single-mode fiber asymmetric-rate EPON ONU, low power budget (PRX10)" },
-	{ 63,   "10G1GbasePRXU2 - One single-mode fiber asymmetric-rate EPON ONU, medium power budget (PRX20)" },
-	{ 64,   "10G1GbasePRXU3 - One single-mode fiber asymmetric-rate EPON ONU, high power budget (PRX30)" },
-	{ 65,   "10GbasePRD1 - One single-mode fiber symmetric-rate EPON OLT, low power budget (PR10)" },
-	{ 66,   "10GbasePRD2 - One single-mode fiber symmetric-rate EPON OLT, medium power budget (PR20)" },
-	{ 67,   "10GbasePRD3 - One single-mode fiber symmetric-rate EPON OLT, high power budget (PR30)" },
-	{ 68,   "10GbasePRU1 - One single-mode fiber symmetric-rate EPON ONU, low and medium power budget" },
-	{ 69,   "10GbasePRU3 - One single-mode fiber symmetric-rate EPON ONU, high power budget (PR30)" },
-	{ 70,   "40GbaseKR4 - 40GBASE-R PCS/PMA over an electrical backplane" },
-	{ 71,   "40GbaseCR4 - 40GBASE-R PCS/PMA over 4 lane shielded copper balanced cable" },
-	{ 72,   "40GbaseSR4 - 40GBASE-R PCS/PMA over 4 lane multimode fiber" },
-	{ 73,   "40GbaseFR - 40GBASE-R PCS/PMA over single mode fiber" },
-	{ 74,   "40GbaseLR4 - 40GBASE-R PCS/PMA over 4 WDM lane single mode fiber" },
-	{ 75,   "100GbaseCR10 - 100GBASE-R PCS/PMA over 10 lane shielded copper balanced cable" },
-	{ 76,   "100GbaseSR10 - 100GBASE-R PCS/PMA over 10 lane multimode fiber" },
-	{ 77,   "100GbaseLR4 - 100GBASE-R PCS/PMA over 4 WDM lane single mode fiber, long reach" },
-	{ 78,   "100GbaseER4 - 100GBASE-R PCS/PMA over 4 WDM lane single mode fiber PMD, extended reach" },
+	{ LLDP_DOT3_MAU_AUI,		"AUI - No internal MAU, view from AUI" },
+	{ LLDP_DOT3_MAU_10BASE5,	"10Base5 - Thick coax MAU" },
+	{ LLDP_DOT3_MAU_FOIRL,		"Foirl - FOIRL MAU" },
+	{ LLDP_DOT3_MAU_10BASE2,	"10Base2 - Thin coax MAU" },
+	{ LLDP_DOT3_MAU_10BASET,	"10BaseT - UTP MAU" },
+	{ LLDP_DOT3_MAU_10BASEFP,	"10BaseFP - Passive fiber MAU" },
+	{ LLDP_DOT3_MAU_10BASEFB,	"10BaseFB - Sync fiber MAU" },
+	{ LLDP_DOT3_MAU_10BASEFL,	"10BaseFL - Async fiber MAU" },
+	{ LLDP_DOT3_MAU_10BROAD36,	"10Broad36 - Broadband DTE MAU" },
+	{ LLDP_DOT3_MAU_10BASETHD,	"10BaseTHD - UTP MAU, half duplex mode" },
+	{ LLDP_DOT3_MAU_10BASETFD,	"10BaseTFD - UTP MAU, full duplex mode" },
+	{ LLDP_DOT3_MAU_10BASEFLHD,	"10BaseFLHD - Async fiber MAU, half duplex mode" },
+	{ LLDP_DOT3_MAU_10BASEFLFD,	"10BaseFLDF - Async fiber MAU, full duplex mode" },
+	{ LLDP_DOT3_MAU_100BASET4,	"100BaseT4 - 4 pair category 3 UTP" },
+	{ LLDP_DOT3_MAU_100BASETXHD,	"100BaseTXHD - 2 pair category 5 UTP, half duplex mode" },
+	{ LLDP_DOT3_MAU_100BASETXFD,	"100BaseTXFD - 2 pair category 5 UTP, full duplex mode" },
+	{ LLDP_DOT3_MAU_100BASEFXHD,	"100BaseFXHD - X fiber over PMT, half duplex mode" },
+	{ LLDP_DOT3_MAU_100BASEFXFD,	"100BaseFXFD - X fiber over PMT, full duplex mode" },
+	{ LLDP_DOT3_MAU_100BASET2HD,	"100BaseT2HD - 2 pair category 3 UTP, half duplex mode" },
+	{ LLDP_DOT3_MAU_100BASET2FD,	"100BaseT2FD - 2 pair category 3 UTP, full duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASEXHD,	"1000BaseXHD - PCS/PMA, unknown PMD, half duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASEXFD,	"1000BaseXFD - PCS/PMA, unknown PMD, full duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASELXHD,	"1000BaseLXHD - Fiber over long-wavelength laser, half duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASELXFD,	"1000BaseLXFD - Fiber over long-wavelength laser, full duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASESXHD,	"1000BaseSXHD - Fiber over short-wavelength laser, half duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASESXFD,	"1000BaseSXFD - Fiber over short-wavelength laser, full duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASECXHD,	"1000BaseCXHD - Copper over 150-Ohm balanced cable, half duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASECXFD,	"1000BaseCXFD - Copper over 150-Ohm balanced cable, full duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASETHD,	"1000BaseTHD - Four-pair Category 5 UTP, half duplex mode" },
+	{ LLDP_DOT3_MAU_1000BASETFD,	"1000BaseTFD - Four-pair Category 5 UTP, full duplex mode" },
+	{ LLDP_DOT3_MAU_10GIGBASEX,	"10GigBaseX - X PCS/PMA, unknown PMD." },
+	{ LLDP_DOT3_MAU_10GIGBASELX4,	"10GigBaseLX4 - X fiber over WWDM optics" },
+	{ LLDP_DOT3_MAU_10GIGBASER,	"10GigBaseR - R PCS/PMA, unknown PMD." },
+	{ LLDP_DOT3_MAU_10GIGBASEER,	"10GigBaseER - R fiber over 1550 nm optics" },
+	{ LLDP_DOT3_MAU_10GIGBASELR,	"10GigBaseLR - R fiber over 1310 nm optics" },
+	{ LLDP_DOT3_MAU_10GIGBASESR,	"10GigBaseSR - R fiber over 850 nm optics" },
+	{ LLDP_DOT3_MAU_10GIGBASEW,	"10GigBaseW - W PCS/PMA, unknown PMD." },
+	{ LLDP_DOT3_MAU_10GIGBASEEW,	"10GigBaseEW - W fiber over 1550 nm optics" },
+	{ LLDP_DOT3_MAU_10GIGBASELW,	"10GigBaseLW - W fiber over 1310 nm optics" },
+	{ LLDP_DOT3_MAU_10GIGBASESW,	"10GigBaseSW - W fiber over 850 nm optics" },
+	{ LLDP_DOT3_MAU_10GIGBASECX4,	"10GigBaseCX4 - X copper over 8 pair 100-Ohm balanced cable" },
+	{ LLDP_DOT3_MAU_2BASETL,	"2BaseTL - Voice grade UTP copper, up to 2700m, optional PAF" },
+	{ LLDP_DOT3_MAU_10PASSTS,	"10PassTS - Voice grade UTP copper, up to 750m, optional PAF" },
+	{ LLDP_DOT3_MAU_100BASEBX10D,	"100BaseBX10D - One single-mode fiber OLT, long wavelength, 10km" },
+	{ LLDP_DOT3_MAU_100BASEBX10U,	"100BaseBX10U - One single-mode fiber ONU, long wavelength, 10km" },
+	{ LLDP_DOT3_MAU_100BASELX10,	"100BaseLX10 - Two single-mode fibers, long wavelength, 10km" },
+	{ LLDP_DOT3_MAU_1000BASEBX10D,	"1000BaseBX10D - One single-mode fiber OLT, long wavelength, 10km" },
+	{ LLDP_DOT3_MAU_1000BASEBX10U,	"1000BaseBX10U - One single-mode fiber ONU, long wavelength, 10km" },
+	{ LLDP_DOT3_MAU_1000BASELX10,	"1000BaseLX10 - Two sigle-mode fiber, long wavelength, 10km" },
+	{ LLDP_DOT3_MAU_1000BASEPX10D,	"1000BasePX10D - One single-mode fiber EPON OLT, 10km" },
+	{ LLDP_DOT3_MAU_1000BASEPX10U,	"1000BasePX10U - One single-mode fiber EPON ONU, 10km" },
+	{ LLDP_DOT3_MAU_1000BASEPX20D,	"1000BasePX20D - One single-mode fiber EPON OLT, 20km" },
+	{ LLDP_DOT3_MAU_1000BASEPX20U,	"1000BasePX20U - One single-mode fiber EPON ONU, 20km" },
+	{ LLDP_DOT3_MAU_10GBASET,	"10GbaseT - Four-pair Category 6A or better, full duplex mode only" },
+	{ LLDP_DOT3_MAU_10GBASELRM,	"10GbaseLRM - R multimode fiber over 1310 nm optics" },
+	{ LLDP_DOT3_MAU_1000BASEKX,	"1000baseKX - X backplane, full duplex mode only" },
+	{ LLDP_DOT3_MAU_10GBASEKX4,	"10GbaseKX4 - 4 lane X backplane, full duplex mode only" },
+	{ LLDP_DOT3_MAU_10GBASEKR,	"10GbaseKR - R backplane, full duplex mode only" },
+	{ LLDP_DOT3_MAU_10G1GBASEPRXD1,	"10G1GbasePRXD1 - One single-mode fiber asymmetric-rate EPON OLT, low power budget (PRX10)" },
+	{ LLDP_DOT3_MAU_10G1GBASEPRXD2, "10G1GbasePRXD2 - One single-mode fiber asymmetric-rate EPON OLT, medium power budget (PRX20)" },
+	{ LLDP_DOT3_MAU_10G1GBASEPRXD3, "10G1GbasePRXD3 - One single-mode fiber asymmetric-rate EPON OLT, high power budget (PRX30)" },
+	{ LLDP_DOT3_MAU_10G1GBASEPRXU1, "10G1GbasePRXU1 - One single-mode fiber asymmetric-rate EPON ONU, low power budget (PRX10)" },
+	{ LLDP_DOT3_MAU_10G1GBASEPRXU2, "10G1GbasePRXU2 - One single-mode fiber asymmetric-rate EPON ONU, medium power budget (PRX20)" },
+	{ LLDP_DOT3_MAU_10G1GBASEPRXU3, "10G1GbasePRXU3 - One single-mode fiber asymmetric-rate EPON ONU, high power budget (PRX30)" },
+	{ LLDP_DOT3_MAU_10GBASEPRD1,	"10GbasePRD1 - One single-mode fiber symmetric-rate EPON OLT, low power budget (PR10)" },
+	{ LLDP_DOT3_MAU_10GBASEPRD2,	"10GbasePRD2 - One single-mode fiber symmetric-rate EPON OLT, medium power budget (PR20)" },
+	{ LLDP_DOT3_MAU_10GBASEPRD3,	"10GbasePRD3 - One single-mode fiber symmetric-rate EPON OLT, high power budget (PR30)" },
+	{ LLDP_DOT3_MAU_10GBASEPRU1,	"10GbasePRU1 - One single-mode fiber symmetric-rate EPON ONU, low and medium power budget" },
+	{ LLDP_DOT3_MAU_10GBASEPRU3,	"10GbasePRU3 - One single-mode fiber symmetric-rate EPON ONU, high power budget (PR30)" },
+	{ LLDP_DOT3_MAU_40GBASEKR4,	"40GbaseKR4 - 40GBASE-R PCS/PMA over an electrical backplane" },
+	{ LLDP_DOT3_MAU_40GBASECR4,	"40GbaseCR4 - 40GBASE-R PCS/PMA over 4 lane shielded copper balanced cable" },
+	{ LLDP_DOT3_MAU_40GBASESR4,	"40GbaseSR4 - 40GBASE-R PCS/PMA over 4 lane multimode fiber" },
+	{ LLDP_DOT3_MAU_40GBASEFR,	"40GbaseFR - 40GBASE-R PCS/PMA over single mode fiber" },
+	{ LLDP_DOT3_MAU_40GBASELR4,	"40GbaseLR4 - 40GBASE-R PCS/PMA over 4 WDM lane single mode fiber" },
+	{ LLDP_DOT3_MAU_100GBASECR10,   "100GbaseCR10 - 100GBASE-R PCS/PMA over 10 lane shielded copper balanced cable" },
+	{ LLDP_DOT3_MAU_100GBASESR10,   "100GbaseSR10 - 100GBASE-R PCS/PMA over 10 lane multimode fiber" },
+	{ LLDP_DOT3_MAU_100GBASELR4,	"100GbaseLR4 - 100GBASE-R PCS/PMA over 4 WDM lane single mode fiber, long reach" },
+	{ LLDP_DOT3_MAU_100GBASEER4,	"100GbaseER4 - 100GBASE-R PCS/PMA over 4 WDM lane single mode fiber PMD, extended reach" },
 	{ 0, NULL }
 };
 #endif
